var a00851 =
[
    [ "PatchTable", "a00993.html", "a00993" ],
    [ "PatchHandle", "a00997.html", "a00997" ]
];